==> mtglifecounter_0.0.1-2.tar.gz: mtglifecounter-0.0.1/src/mainwindow.cpp <==
#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "PlayerSheet.h"
#include <QDebug>
#include <QtGui>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow),
    list(new QList<PlayerSheet*>)
{
    ui->setupUi(this);

    connect(ui->actionAdd_Player,SIGNAL(triggered()),this,SLOT(AddPlayer()));
    connect(ui->actionFlip_Orientation,SIGNAL(triggered()),this,SLOT(FlipOrientation()));
    connect(ui->actionFlip_Coin,SIGNAL(triggered()),this,SLOT(FlipCoin()));
    connect(ui->actionReset, SIGNAL(triggered()), this,SLOT(ResetSheets()));

    AddPlayer();
    AddPlayer();
    coinLabel = NULL;
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::FlipOrientation()
{

    #ifdef Q_WS_MAEMO_5
    static bool portraitMode = false;
    if(portraitMode == false)
    {
        setAttribute(Qt::WA_Maemo5PortraitOrientation,true);
        portraitMode = true;
    }
    else
    {
        setAttribute(Qt::WA_Maemo5PortraitOrientation,false);
        portraitMode = false;
    }
    emit StartTimerSignal();
    #endif
}



void MainWindow::AddPlayer()
{
    PlayerSheet * sheet = new PlayerSheet(this);
    list->append(sheet);
    connect(sheet,SIGNAL(closeSheetSignal(PlayerSheet*)),this,SLOT(SheetClose(PlayerSheet*)));
    ui->horizontalLayout->addWidget(sheet);
    emit StartTimerSignal();
}

void MainWindow::SheetClose(PlayerSheet* sheet)
{
    for(int i = 0; i < list->count() ; i++)
    {
        if(list->at(i) == sheet)
        {
           list->at(i)->close();
            list->removeAt(i);
            break;
        }
    }
    emit StartTimerSignal();
}

void MainWindow::FlipCoin()
{
    int roll = qrand() % ((1 + 1) - 0) + 0;
    if(coinLabel != NULL)
    {
        delete coinLabel;
        coinLabel = NULL;
    }
    coinLabel = new QLabel(this);
    if(roll == 0)
    {
        QPixmap pixmap(":/images/heads.png");
        coinLabel->setPixmap(pixmap);
        coinLabel->setGeometry(pixmap.rect());
        coinLabel->move((this->width()/2) - coinLabel->width()/2,(this->height()/2) - coinLabel->height()/2);
        coinLabel->show();
    }
    else
    {
        QPixmap pixmap(":/images/tails.png");
        coinLabel->setPixmap(pixmap);
        coinLabel->setGeometry(pixmap.rect());
        coinLabel->move((this->width()/2) - coinLabel->width()/2,(this->height()/2) - coinLabel->height()/2);
        coinLabel->show();
    }
}

void MainWindow::mousePressEvent(QMouseEvent *)
{
    if(coinLabel != NULL)
    {
        delete coinLabel;
        coinLabel = NULL;
    }    
}

void MainWindow::keyPressEvent(QKeyEvent *)
{    
    if(coinLabel != NULL)
    {
        delete coinLabel;
        coinLabel = NULL;
    }
}

void MainWindow::ResetSheets()
{
    for(int i = 0; i < list->count() ; i++)
    {
        list->at(i)->Reset();
    }

}

==> mtglifecounter_0.0.1-4.tar.gz: mtglifecounter-0.0.1/src/mainwindow.cpp <==
#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "PlayerSheet.h"
#include <QDebug>
#include <QtGui>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow),
    list(new QList<PlayerSheet*>)
{
    ui->setupUi(this);

    connect(ui->actionAdd_Player,SIGNAL(triggered()),this,SLOT(AddPlayer()));
    connect(ui->actionFlip_Orientation,SIGNAL(triggered()),this,SLOT(FlipOrientation()));
    connect(ui->actionFlip_Coin,SIGNAL(triggered()),this,SLOT(FlipCoin()));
    connect(ui->actionReset, SIGNAL(triggered()), this,SLOT(ResetSheets()));

    AddPlayer();
    AddPlayer();
    coinLabel = NULL;


}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::FlipOrientation()
{

    #ifdef Q_WS_MAEMO_5
    static bool portraitMode = false;
    if(portraitMode == false)
    {
        setAttribute(Qt::WA_Maemo5PortraitOrientation,true);
        portraitMode = true;
    }
    else
    {
        setAttribute(Qt::WA_Maemo5PortraitOrientation,false);
        portraitMode = false;
    }
    emit StartTimerSignal(1000);
    #endif
}



void MainWindow::AddPlayer()
{
    PlayerSheet * sheet = new PlayerSheet(this);
    list->append(sheet);
    connect(sheet,SIGNAL(closeSheetSignal(PlayerSheet*)),this,SLOT(SheetClose(PlayerSheet*)));
    ui->horizontalLayout->addWidget(sheet);
    emit StartTimerSignal(100);
}

void MainWindow::SheetClose(PlayerSheet* sheet)
{
    for(int i = 0; i < list->count() ; i++)
    {
        if(list->at(i) == sheet)
        {
           list->at(i)->close();
            list->removeAt(i);
            break;
        }
    }
    emit StartTimerSignal(100);
}

void MainWindow::FlipCoin()
{
    int roll = qrand() % ((1 + 1) - 0) + 0;
    if(coinLabel != NULL)
    {
        delete coinLabel;
        coinLabel = NULL;
    }
    coinLabel = new QLabel(this);
    if(roll == 0)
    {
        QPixmap pixmap(":/images/heads.png");
        coinLabel->setPixmap(pixmap);
        coinLabel->setGeometry(pixmap.rect());
        coinLabel->move((this->width()/2) - coinLabel->width()/2,(this->height()/2) - coinLabel->height()/2);
        coinLabel->show();
    }
    else
    {
        QPixmap pixmap(":/images/tails.png");
        coinLabel->setPixmap(pixmap);
        coinLabel->setGeometry(pixmap.rect());
        coinLabel->move((this->width()/2) - coinLabel->width()/2,(this->height()/2) - coinLabel->height()/2);
        coinLabel->show();
    }
}

void MainWindow::mousePressEvent(QMouseEvent *)
{    
    deleteCoin();
}

void MainWindow::deleteCoin()
{
    if(coinLabel != NULL)
    {
        delete coinLabel;
        coinLabel = NULL;
    }
}

bool MainWindow::event(QEvent *event)
{
    if(event->type() == QEvent::KeyPress || event->type() == QEvent::ShortcutOverride)
    {
        deleteCoin();
    }
    return QMainWindow::event(event);
}

void MainWindow::ResetSheets()
{
    for(int i = 0; i < list->count() ; i++)
    {
        list->at(i)->Reset();
    }

}
